#include <iostream>
#include <utility>
#include <vector>
#include <cmath>
#include <algorithm>
#include <map>
#include <queue>
using namespace std;

const int INF = 1e9 + 1, N = 2e5 + 1;
template <typename T, typename P>
istream& operator >> (istream& in, pair<T, P>& p) {
	in >> p.first >> p.second;
	return in;
}

template <typename T, typename P>
ostream& operator << (ostream& out, pair<T, P> const& p) {
	out << p.first << p.second;
	return out;
}

template<typename T>
istream& operator >> (istream& in, vector<T>& vec) {
	for (T& el : vec) {
		in >> el;
	}

	return in;
}

template <typename T>
ostream& operator << (ostream& out, vector<T> const& vec) {
	for (T const& el : vec) {
		out << el << ' ';
	}
	return out;
}

struct act {
	int	pos, t, a, b;
	bool operator < (act const& other) {
		if (pos != other.pos) {
			return pos < other.pos;
		}

		return t < other.t;
	}
};

class RangeTree {
	int n;
	vector<long long> t, p;

	void push_t(int v, int l, int r) {
		if (p[v] == 0) {
			return;
		}

		if (r - l > 1) {
			p[2 * v] += p[v];
			p[2 * v + 1] += p[v];
		}

		t[v] += p[v];
		p[v] = 0;
	}

	void upd_t(int v, int l, int r, int L, int R, int X) {
		push_t(v, l, r);

		if (R <= l || r <= L ) {
			return;
		}

		if (L <= l && r <= R) {
			p[v] += X;
			push_t(v, l, r);
			return;
		}

		upd_t(2 * v, l, (l + r) / 2, L, R, X);
		upd_t(2 * v + 1, (l + r) / 2, r, L, R, X);

		t[v] = max(t[2 * v], t[2 * v + 1]);
	}

	long long get_t(int v, int l, int r, int L, int R) {
		push_t(v, l, r);
		if (R <= l || r <= L) {
			return -INF;
		}

		if (L <= l && r <= R) {
			return t[v];
		}

		return max(get_t(2 * v, l, (l + r) / 2, L, R), get_t(2 * v + 1, (l + r) / 2, r, L, R));
	}

	void build_t(int v, int l, int r, vector<long long> const& val) {
		if (r - l == 1) {
			t[v] = val[l];
			return;
		}

		build_t(2 * v, l, (l + r) / 2, val);
		build_t(2 * v + 1, (l + r) / 2, r, val);
		t[v] = max(t[2 * v], t[2 * v + 1]);
	}

public:
	RangeTree(vector<long long> const& val) : n(val.size()), t(4 * n), p(4 * n) {
		build_t(1, 0, n, val);
	}

	void upd(int p, int x) {
		upd_t(1, 0, n, p, n, x);
	}

	long long get(int l, int r) {
		return get_t(1, 0, n, l, r);
	}
};

int main() {
	ios_base::sync_with_stdio(false);
	cin.tie(0);

	int n, m, p;
	cin >> n >> m >> p;

	vector<pair<int, int>> weapon, armor, w_in(n), a_in(m);
	cin >> w_in >> a_in;

	sort(w_in.begin(), w_in.end());
	sort(a_in.begin(), a_in.end());

	for (auto p : w_in) {
		auto val = p.first;
		auto cost = p.second;
		while (!weapon.empty() && weapon.back().second >= cost) {
			weapon.pop_back();
		}
		weapon.push_back({val, cost});
	}
	vector<pair<int, int>>().swap(w_in);

	for (auto p : a_in) {
		auto val = p.first;
		auto cost = p.second;
		while (!armor.empty() && armor.back().second >= cost) {
			armor.pop_back();
		}
		armor.push_back({ val, cost });
	}

	vector<long long> power_cost(weapon.back().first + 1, -INF);
	for (auto p : weapon) {
		auto val = p.first;
		auto cost = p.second;
		power_cost[val] = -cost;
	}

	for (int i = power_cost.size() - 1; i > 0; i--) {
		power_cost[i - 1] = max(power_cost[i - 1], power_cost[i]);
	}

	RangeTree cost_calc(power_cost);

	vector<act> line;

	for (int i = 0, x, y, z; i < p; i++) {
		cin >> x >> y >> z;
		line.push_back({y + 1, 0, x + 1, z});
	}

	for (auto p : armor) {
		auto val = p.first;
		auto cost = p.second;
		line.push_back({ val, 1, cost, 0 });
	}

	sort(line.begin(), line.end());
	long long ans = -INF, power_max = power_cost.size();

	for (auto itm : line) {
		auto t = itm.t;
		auto a = itm.a;
		auto b = itm.b;
		if (t == 0) {
			cost_calc.upd(a, b);
		} else {
			ans = max(ans, cost_calc.get(0, power_max) - a);
		}
	}

	cout << ans << '\n';
}