import java.lang.reflect.Array;
import java.util.*;
import java.io.*;

import static java.lang.Math.*;

public class Main {
    static FastScanner sc;
    static int n, m, p, INF = Integer.MAX_VALUE / 2;
    static Info[] weapons, armors, newWeapons, newArmors;
    static Enemy[] enemies, sortedEnemies;
    static TreeSet<Info> weapon, armor;

    public static void main(String[] args) {
        sc = new FastScanner(System.in);
        PrintWriter pw = new PrintWriter(System.out);
        read();
        preWork();
        long ans = -INF;
        for (int i = 0; i < p; i++)
            ans = max(ans, enemies[i].money - calc(enemies[i].def, enemies[i].att));
        pw.print(ans);
        pw.close();
    }

    public static long calc(int attack, int hp) {
        int cost = 0;
        int l = -1;
        int r = newWeapons.length - 1;
        while (r - l > 1) {
            int m = l + (r - l) / 2;
            if (newWeapons[m].power <= attack)
                l = m;
            else
                r = m;
        }
        if (newWeapons[r].power <= attack)
            return INF;
        cost += newWeapons[r].cost;
         l = -1;
         r = newArmors.length - 1;
        while (r - l > 1) {
            int m = l + (r - l) / 2;
            if (newArmors[m].power <= hp)
                l = m;
            else
                r = m;
        }
        if (newArmors[r].power <= hp)
            return INF;
        return cost + newArmors[r].cost;
    }

    public static void preWork() {
        weapon = new TreeSet<>(new InfoComp());
        for (int i = 0; i < n; i++)
            weapon.add(weapons[i]);
        Arrays.sort(weapons, new InfoComp());
        for (int i = 1; i < n; i++)
            if (weapons[i].power >= weapons[i - 1].power && weapons[i].cost <= weapons[i - 1].cost)
                weapon.remove(weapons[i - 1]);
        newWeapons = new Info[weapon.size()];
        int ind = 0;
        for (Info weap : weapon)
            newWeapons[ind++] = weap;
        //----------------------------
        armor = new TreeSet<>(new InfoComp());
        for (int i = 0; i < m; i++)
            armor.add(armors[i]);
        Arrays.sort(armors, new InfoComp());
        for (int i = 1; i < m; i++)
            if (armors[i].power >= armors[i - 1].power && armors[i].cost <= armors[i - 1].cost)
                armor.remove(armors[i - 1]);
        newArmors = new Info[armor.size()];
        ind = 0;
        for (Info arm : armor)
            newArmors[ind++] = arm;
        //----------------------------
        Arrays.sort(sortedEnemies, new EnemyCompAtt());
        int money = 0;
        for (int i = 0; i < p; i++) {
            money += sortedEnemies[i].money;
            enemies[sortedEnemies[i].index].money = min(enemies[sortedEnemies[i].index].money, money);
        }
        //----------------------------
        Arrays.sort(sortedEnemies, new EnemyCompDef());
        money = 0;
        for (int i = 0; i < p; i++) {
            money += sortedEnemies[i].money;
            enemies[sortedEnemies[i].index].money = min(enemies[sortedEnemies[i].index].money, money);
        }
    }

    public static void read() {
        n = sc.nextInt();
        m = sc.nextInt();
        p = sc.nextInt();
        weapons = new Info[n];
        armors = new Info[m];
        enemies = new Enemy[p];
        sortedEnemies = new Enemy[p];
        for (int i = 0; i < n; i++)
            weapons[i] = new Info(sc.nextInt(), sc.nextInt());
        for (int i = 0; i < m; i++)
            armors[i] = new Info(sc.nextInt(), sc.nextInt());
        for (int i = 0; i < p; i++) {
            enemies[i] = new Enemy(sc.nextInt(), sc.nextInt(), INF, i);
            sortedEnemies[i] = new Enemy(enemies[i].att, enemies[i].def, sc.nextInt(), i);
        }
    }
}

class Enemy {
    int att, def, money, index;

    public Enemy(int att, int def, int money, int index) {
        this.att = att;
        this.def = def;
        this.money = money;
        this.index = index;
    }
}

class EnemyCompDef implements Comparator<Enemy> {
    public int compare(Enemy o1, Enemy o2) {
        return Integer.compare(o1.def, o2.def) * 2 + Integer.compare(o1.index, o2.index);
    }
}


class EnemyCompAtt implements Comparator<Enemy> {
    public int compare(Enemy o1, Enemy o2) {
        return Integer.compare(o1.att, o2.att) * 2 + Integer.compare(o1.index, o2.index);
    }
}

class Info {
    int power, cost;

    public Info(int power, int cost) {
        this.power = power;
        this.cost = cost;
    }
}

class InfoComp implements Comparator<Info> {
    public int compare(Info o1, Info o2) {
        return Integer.compare(o1.power, o2.power) * 2 + Integer.compare(o2.cost, o1.cost);
    }
}

class FastScanner {
    static BufferedReader br;
    static StringTokenizer st = new StringTokenizer("");

    public FastScanner(InputStream inputStream) {
        br = new BufferedReader(new InputStreamReader(inputStream));
    }

    public FastScanner(String fileName) throws FileNotFoundException {
        br = new BufferedReader(new FileReader(fileName));
    }

    public boolean hasNext() {
        try {
            while (!st.hasMoreTokens())
                st = new StringTokenizer(br.readLine());
            return true;
        } catch (Exception e) {
            return false;
        }
    }

    public double nextDouble() {
        return Double.parseDouble(next());
    }

    public long nextLong() {
        return Long.parseLong(next());
    }

    public int nextInt() {
        return Integer.parseInt(next());
    }

    public String next() {
        hasNext();
        return st.nextToken();
    }
}
