// Codeforces - mycopka

#include <algorithm>
#include <iostream>
#include <vector>
#include <string>
#include <queue>
#include <map>

using namespace std;

typedef int64_t ll;

const ll N = (ll)(1e6) + 666;
const ll INF = (ll)(1e17) + 666;

struct Result {
	ll cnt_1, cnt_0, cnt_inv;

	Result() {
		cnt_0 = cnt_1 = cnt_inv = 0;
	}

	Result(char ch) {
		if (ch == '0') {
			cnt_0 = 1;
			cnt_1 = 0;
		}
		if (ch == '1') {
			cnt_0 = 0;
			cnt_1 = 1;
		}
		cnt_inv = 0;
	}

	Result(Result left, Result right) {
		cnt_0 = left.cnt_0 + right.cnt_0;
		cnt_1 = left.cnt_1 + right.cnt_1;
		cnt_inv = left.cnt_inv + right.cnt_inv + left.cnt_0 * right.cnt_1;
	}

	bool operator ==(Result other) {
		if (cnt_1 != other.cnt_1) {
			return false;
		}
		if (cnt_0 != other.cnt_0) {
			return false;
		}
		if ((cnt_inv & 1) != (other.cnt_inv & 1)) {
			return false;
		}
		return true;
	}
};

typedef struct Node* pNode;
struct Node {
	pNode child_left, child_right;
	ll left, right;
	Result result;

	Node(ll left, ll right)
		: left(left), right(right) {
			child_left = child_right = nullptr;
		}
};

pNode build(ll left, ll right, string& s) {
	pNode root = new Node(left, right);
	if (right - left == 1) {
		root->result = Result(s[left]);
		return root;
	}
	root->child_left = build(left, left + right >> 1, s);
	root->child_right = build(left + right >> 1, right, s);
	root->result = Result(root->child_left->result, root->child_right->result);
	return root;
}

Result get(pNode root, ll left, ll right) {
	if (root->left >= right || root->right <= left) {
		return Result();
	}
	if (root->left >= left && root->right <= right) {
		return root->result;
	}
	return Result(get(root->child_left, left, right), get(root->child_right, left, right));
}

int main() {
	ios_base::sync_with_stdio(false);
	cout.tie(nullptr);
	cin.tie(nullptr);

	ll n;
	cin >> n;
	string s;
	cin >> s;
	pNode root = build(0, n, s);

	ll m;
	cin >> m;
	for (ll i = 0; i < m; ++i) {
		ll l1, l2, len;
		cin >> l1 >> l2 >> len;
		if (get(root, l1 - 1, l1 + len - 1) == get(root, l2 - 1, l2 + len - 1)) {
			cout << "YES" << "\n";
		} else {
			cout << "NO" << "\n";
		}
	}

	return 0;
}
