// Codeforces - mycopka

#include <algorithm>
#include <iostream>
#include <vector>
#include <string>
#include <queue>
#include <map>

using namespace std;

typedef int64_t ll;

const ll N = (ll)(1e6) + 666;
const ll INF = (ll)(1e17) + 666;
const ll MOD = 2286661337;
const ll P = 13;

ll power(ll x, ll n) {
	if (n == 0) {
		return 1;
	}
	if (n & 1) {
		return x * power(x * x % MOD, n >> 1) % MOD;
	}
	return power(x * x % MOD, n >> 1);
}

struct Result {
	ll cnt_1, cnt_0;
	ll hash;
	ll sz;
	ll f_0, f_n;

	Result() {
		cnt_0 = cnt_1 = 0;
		hash = 0;
		sz = 0;
		f_0 = f_n = 0;
	}

	Result(char ch) {
		if (ch == '0') {
			cnt_0 = 1;
			cnt_1 = 0;
			f_0 = f_n = 0;
			hash = 1;
			sz = 1;
		}
		if (ch == '1') {
			cnt_0 = 0;
			cnt_1 = 1;
			f_0 = f_n = 1;
			hash = 0;
			sz = 0;
		}
	}

	Result(Result left, Result right) {
		if (left.sz == 0 && left.cnt_1 == 0) {
			cnt_0 = right.cnt_0;
			cnt_1 = right.cnt_1;
			f_0 = right.f_0;
			f_n = right.f_n;
			hash = right.hash;
			sz = right.sz;
		} else if (right.sz == 0 && right.cnt_1 == 0) {
			cnt_0 = left.cnt_0;
			cnt_1 = left.cnt_1;
			f_0 = left.f_0;
			f_n = left.f_n;
			hash = left.hash;
			sz = left.sz;
		} else {
			cnt_0 = left.cnt_0 + right.cnt_0;
			cnt_1 = left.cnt_1 + right.cnt_1;
			if (left.f_n == 1 && right.f_0 == 1) {
				left.f_n = 0;
				if (left.cnt_0 == 0) {
					left.f_0 = 0;
				}
				right.f_0 = 0;
				if (right.cnt_0 == 0) {
					right.f_n = 0;
				}
			}
			if (left.f_n == 0 &&  right.f_0 == 0) {
				hash = left.hash + power(P, left.sz - 1) * (right.hash);
				sz = left.sz + right.sz - 1;
			} else {
				hash = left.hash + power(P, left.sz) * right.hash;
				sz = left.sz + right.sz;
			}
			f_0 = left.f_0;
			f_n = right.f_n;
		}
	}

	bool operator ==(Result other) {
		if (cnt_1 != other.cnt_1) {
			return false;
		}
		if (cnt_0 != other.cnt_0) {
			return false;
		}
		if (hash != other.hash) {
			return false;
		}
		if (sz != other.sz) {
			return false;
		}
		if (f_0 != other.f_0) {
			return false;
		}
		if (f_n != other.f_n) {
			return false;
		}
		return true;
	}
};

typedef struct Node* pNode;
struct Node {
	pNode child_left, child_right;
	ll left, right;
	Result result;

	Node(ll left, ll right)
		: left(left), right(right) {
			child_left = child_right = nullptr;
		}
};

pNode build(ll left, ll right, string& s) {
	pNode root = new Node(left, right);
	if (right - left == 1) {
		root->result = Result(s[left]);
		return root;
	}
	root->child_left = build(left, left + right >> 1, s);
	root->child_right = build(left + right >> 1, right, s);
	root->result = Result(root->child_left->result, root->child_right->result);
	return root;
}

Result get(pNode root, ll left, ll right) {
	if (root->left >= right || root->right <= left) {
		return Result();
	}
	if (root->left >= left && root->right <= right) {
		return root->result;
	}
	return Result(get(root->child_left, left, right), get(root->child_right, left, right));
}

int main() {
	ios_base::sync_with_stdio(false);
	cout.tie(nullptr);
	cin.tie(nullptr);

	ll n;
	cin >> n;
	string s;
	cin >> s;
	pNode root = build(0, n, s);

	ll m;
	cin >> m;
	for (ll i = 0; i < m; ++i) {
		ll l1, l2, len;
		cin >> l1 >> l2 >> len;
		Result x = get(root, l1 - 1, l1 + len - 1);
		Result y = get(root, l2 - 1, l2 + len - 1);
		if (x == y) {
			cout << "YES" << "\n";
		} else {
			cout << "NO" << "\n";
		}
	}

	return 0;
}
