#include <iostream>
#include <vector>
#include <string>
#include <algorithm>


using namespace std;


const int INF = (int)1e9 + 5;


#define left(v) 2 * v + 1
#define right(v) 2 * v + 2
#define parent(v) (v - 1) / 2

class LST {
    vector<int> data;
    int m;

    void update(int v) {
        data[v] = data[left(v)] + data[right(v)];
    }

public:
    LST(int n) {
        for (m = 1; m < n; m <<= 1);
        --m;

        data.resize(2 * m + 1);
    }

    void add(int i, int v) {
        i += m;

        data[i] += v;

        while (i) {
            i = parent(i);

            update(i);
        }
    }

    int get(int L, int R) {
        L += m;
        R += m - 1;

        int res = 0;
        while (L < R) {
            if (L % 2 == 0) {
                res += data[L++];
            }

            L = parent(L);

            if (R % 2 == 1) {
                res += data[R--];
            }

            R = parent(R);
        }

        if (L == R) {
            res += data[L];
        }

        return res;
    }
};


void optimize() {
    ios_base::sync_with_stdio(false);
    cin.tie(0);
    cout.tie(0);
}


const int MAXC = (int)1e6 + 1;


struct M {
    int x, y, z;

    M() {

    }

    M(int _x, int _y, int _z) : x(_x), y(_y), z(_z) {

    }

    bool operator<(const M &a) {
        return x < a.x;
    }
};


void F(vector<int> &a, vector<int> &ca, vector<int> &na, vector<int> &nca) {
    int n = a.size();

    vector<int> acost(MAXC, 0);
    for (int i = 0; i < n; ++i) {
        int df = a[i];
        int cc = ca[i];

        if (acost[df] == 0 || acost[df] > cc) {
            acost[df] = cc;
        }
    }

    int lcost = INF;
    for (int i = MAXC - 1; i >= 0; --i) {
        if (acost[i] == 0) {
            continue;
        }

        int cc = acost[i];

        if (cc >= lcost) {
            continue;
        }

        lcost = cc;
        na.push_back(i);
        nca.push_back(cc);
    }

    reverse(na.begin(), na.end());
    reverse(nca.begin(), nca.end());
}


int main() {
    optimize();

    int n, m, p;
    cin >> n >> m >> p;

    vector<int> a(n), ca(n), b(m), cb(m), x(p), y(p), z(p);
    for (int i = 0; i < n; ++i) {
        cin >> a[i] >> ca[i];
    }

    for (int i = 0; i < m; ++i) {
        cin >> b[i] >> cb[i];
    }

    for (int i = 0; i < p; ++i) {
        cin >> y[i] >> x[i] >> z[i];
    }

    vector<M> ms(p);
    for (int i = 0; i < p; ++i) {
        ms[i] = M(x[i], y[i], z[i]);
    }

    sort(ms.begin(), ms.end());

    vector<int> na, nca, nb, ncb;
    F(a, ca, na, nca);
    F(b, cb, nb, ncb);

    int answ = -nca[0] - ncb[0];

    LST tree(MAXC);
    int last_atk = 0;
    int cur_weap = 0;
    for (int i = 0; i < p; ++i) {
        M cm = ms[i];

        if (cm.x != last_atk) {
            last_atk = cm.x;

            for (int j = i; j < p; ++j) {
                if (ms[j].x != cm.x) {
                    break;
                }

                tree.add(ms[j].y, ms[j].z);
            }
        }

        while (na[cur_weap] <= last_atk) {
            if (++cur_weap == n) {
                break;
            }
        }

        if (cur_weap == n) {
            break;
        }

        int def = ms[i].y;
        int cur_arm = upper_bound(nb.begin(), nb.end(), def) - nb.begin();

        if (cur_arm == m) {
            continue;
        }

        int loss = nca[cur_weap] + ncb[cur_arm];

        int gain = tree.get(0, nb[cur_arm]);

        if (gain - loss > answ) {
            answ = gain - loss;
        }
    }

    cout << answ;

    return 0;
}
