#include <iostream>
#include <vector>
#include <queue>
#include <cstring>
#include <algorithm>

using namespace std;

const int N = 2e5 + 7, H = 20, K = 350, INF = 1e9 + 7;
vector <int> g[N];
vector <int> euler;
pair <int, int> best[N];
int tin[N], tout[N], beg[N], depth[N];
int T = 0;
int sparse[H][2 * N];
int color[N];
bool vis[N];
int dist[N];

void dfs(int v, int p = -1, int d = 0) {
    depth[v] = d;
    beg[v] = euler.size();
    euler.push_back(v);
    tin[v] = T++;
    for (int u : g[v]) {
        if (u == p) continue;
        dfs(u, v, d + 1);
        euler.push_back(v);
    }
    tout[v] = T - 1;
}

bool is_ancestor(int v, int u) {
    return (tin[v] <= tin[u] && tout[u] <= tout[v]);
}

void build_sparse() {
    int n = euler.size();
    for (int i = 0; i < n; i++) sparse[0][i] = euler[i];
    for (int i = 1; i < H; i++) {
        int len = 1 << i;
        for (int j = 0; j + len < n; j++) {
            int b = j + len / 2;
            if (tin[sparse[i - 1][j]] < tin[sparse[i - 1][b]]) sparse[i][j] = sparse[i - 1][j];
            else sparse[i][j] = sparse[i - 1][b];
        }
    }
}

int get_lca(int v, int u) {
    int l = beg[v], r = beg[u];
    if (l > r) swap(l, r);
    int len = r - l + 1;
    int t = 31 - __builtin_clz(len);
    int ln = (1 << t);
    int a = sparse[t][l], b = sparse[t][r - ln + 1];
    if (tin[a] < tin[b]) return a;
    return b;
}

struct virus{
    int start, s, num;
    virus() {}
    virus(int start, int s, int num): start(start), s(s), num(num) {}
};

void dump(int n, vector <pair <int, int>> &vir, vector <int> &imp) {
    //cout << 59 << endl;
    queue <int> q;
    memset(vis, 0, sizeof(vis));
    int k = vir.size();
    for (int i = 0; i < k; i++) {
        vis[vir[i].first] = 1;
        color[vir[i].first] = i;
        q.push(vir[i].first);
    }
    while (!q.empty()) {
        //cout << 68 << endl;
        queue <int> cur; 
        int cl = color[q.front()];
        //cout << q.front() << endl;
        while (!q.empty() && color[q.front()] == cl) {
            cur.push(q.front());
            dist[q.front()] = 0;
            q.pop();
        }
        int maxi = vir[cl].second;
        while (!cur.empty()) {
            int v = cur.front();
            cur.pop();
            //cout << v << endl;
            for (int u : g[v]) {
                if (!vis[u]) {
                    vis[u] = 1;
                    color[u] = cl;
                    dist[u] = dist[v] + 1;
                    if (dist[u] == maxi) q.push(u);
                    else cur.push(u);
                }
            }
        }
    }
    for (int elem : imp) {
        cout << color[elem] + 1 << ' ';
    }
    cout << "\n";
} 

bool cmp(virus a, virus b) {
    return (tin[a.start] < tin[b.start]);
}

bool on_vert_path(int v, int u, int x) {
    return (is_ancestor(v, x) && is_ancestor(x, u));
}

bool on_path(int v, int u, int x) {
    int lca = get_lca(v, u);
    return (on_vert_path(lca, v, x) || on_vert_path(lca, u, x));
}

int get_len(int v, int u) {
    int lca = get_lca(v, u);
    return (depth[v] + depth[u] - 2 * depth[lca]);
}

void clever(int n, vector <pair <int, int>> &vir, vector <int> &imp) {
    int k = vir.size();
    vector <virus> v;
    for (int i = 0; i < k; i++) v.push_back(virus(vir[i].first, vir[i].second, i));
    sort(v.begin(), v.end(), cmp);
    for (int city : imp) {
        vector <int> st;
        best[v[0].start] = {v[0].num, 0};
        best[city] = {INF, INF};
        st.push_back(city);
        st.push_back(v[0].start);
        for (int i = 1; i < k; i++) {
            int c = v[i].start;
            best[c] = {v[i].num, 0};
            while (!st.empty()) {
                int lst = st.back();
                if (!on_path(city, c, lst)) {
                    st.pop_back();
                    int cl = best[lst].first;
                    int len = (get_len(vir[cl].first, city) + vir[cl].second - 1) / vir[cl].second;
                    best[st.back()] = min(best[st.back()], {len, cl});
                } else break;
            }
            st.push_back(v[i].start);
        }
        while (!st.empty()) {
            int lst = st.back();
            st.pop_back();
            int cl = best[lst].first;
            int len = (get_len(vir[cl].first, city) + vir[cl].second - 1) / vir[cl].second;
            best[st.back()] = min(best[st.back()], {len, cl});
        }
        cout << best[city].second + 1 << ' ';
    }
    cout << "\n";
}

signed main() {
    freopen("input.txt", "r", stdin);
    ios_base :: sync_with_stdio(0);
    cin.tie(0);
    int n;
    cin >> n;
    for (int i = 0; i < n - 1; i++) {
        int v, u;
        cin >> v >> u;
        g[v].push_back(u);
        g[u].push_back(v);
    }
    dfs(1);
    build_sparse();
    int q;
    cin >> q;
    for (int j = 0; j < q; j++) {
        int k, m;
        cin >> k >> m;
        vector <pair <int, int>> vir(k);
        vector <int> imp(m);
        for (int i = 0; i < k; i++) cin >> vir[i].first >> vir[i].second;
        for (int i = 0; i < m; i++) cin >> imp[i];
        if (k > K) dump(n, vir, imp);
        else clever(n, vir, imp);
    }
}

