#define CRT_SECURE_NO_WARNINGS

#include <iostream>
#include <algorithm>
#include <cmath>
#include <string>
#include <vector>
#include <map>
#include <set>
#include <queue>
#include <assert.h>

using namespace std;

typedef long long ll;
typedef unsigned long long ull;
const ll INF = 1e18;
const double PI = acos(-1.0);

const int MAX_N = 200005;
int n, m, p;
ll A[MAX_N], CA[MAX_N];
ll B[MAX_N], CB[MAX_N];
pair<ll, ll> pr[MAX_N];
ll X[MAX_N], Y[MAX_N], Z[MAX_N];
vector<pair<ll, pair<ll, bool>>> ev;
ll tree[MAX_N * 4];
ll z[MAX_N * 4];

void push(int v)
{
	tree[v] += z[v];
	if (v * 2 < MAX_N * 4) z[v * 2] += z[v];
	if (v * 2 + 1 < MAX_N * 4) z[v * 2 + 1] += z[v];
	z[v] = 0;
}

void build_tree(int v, int left, int right)
{
	if (left == right)
	{
		tree[v] = CB[left];
		return;
	}

	int mid = (left + right) / 2;
	build_tree(v*2, left, mid);
	build_tree(v*2+1, mid + 1, right);
	tree[v] = max(tree[v * 2], tree[v * 2 + 1]);
}

ll get_tree(int v, int left, int right, int l, int r)
{
	if (left > r || right < l)
	{
		return -INF;
	}
	if (z[v] != 0)
	{
		push(v);
	}
	if (left >= l && right <= r)
	{
		return tree[v];
	}

	int mid = (left + right) / 2;
	ll g1 = get_tree(v*2, left, mid, l, r);
	ll g2 = get_tree(v*2+1, mid + 1, right, l, r);
	return max(g1, g2);
}

void add_tree(int v, int left, int right, int l, int r, ll x)
{
	if (left > r || right < l)
	{
		return;
	}
	if (left >= l && right <= r)
	{
		z[v] += x;
		return;
	}

	push(v);
	int mid = (left + right) / 2;
	add_tree(v*2, left, mid, l, r, x);
	add_tree(v*2+1, mid + 1, right, l, r, x);
	tree[v] = max(tree[v * 2], tree[v * 2 + 1]);
}

int main()
{
	ios::sync_with_stdio(false);

	cin >> n >> m >> p;
	for (int i=0; i<n; i++)
	{
		cin >> A[i] >> CA[i];
		ev.push_back(make_pair(A[i], make_pair(i, 0)));
	}

	for (int i=0; i<m; i++)
	{
		cin >> pr[i].first >> pr[i].second;
	}
	sort(pr, pr + m);
	for (int i=0; i<m; i++)
	{
		B[i] = pr[i].first;
		CB[i] = -pr[i].second;
	}
	build_tree(1, 0, m - 1);

	for (int i=0; i<p; i++)
	{
		cin >> X[i] >> Y[i] >> Z[i];
		ev.push_back(make_pair(X[i], make_pair(i, 1)));
	}

	sort(ev.begin(), ev.end());
	int sz = ev.size();
	ll res = -INF;
	for (int i=0; i<sz; i++)
	{
		bool tp = ev[i].second.second;
		int id = ev[i].second.first;
		if (tp == 1)
		{
			int l = -1, r = m;
			int mid;
			while (l < r - 1)
			{
				mid = (l + r) / 2;
				if (B[mid] <= Y[id])
				{
					l = mid;
				}
				else
				{
					r = mid;
				}
			}
			if (r < m)
			{
				add_tree(1, 0, m-1, r, m-1, Z[id]);
			}
		}
		else
		{
			ll sum = get_tree(1, 0, m-1, 0, m-1) - CA[id];
			res = max(res, sum);
		}
	}

	cout << res;

	//system("pause");
	return 0;
}