#pragma GCC optimize("Ofast,unroll-loops,no-stack-protector,fast-math")
#pragma GCC target("sse,sse2,sse3,ssse3,sse4,popcnt,avx,avx2,mmx,tune=native")
#include <iostream>
#include <vector>
#include <set>
#include <string>
#include <queue>
#include <random>
#include <ctime>

using namespace std;

#define ll long long
#define ld long double
#define pll pair<ll, ll>

ll const INF = 1e18, N = 1e6, P = 257, M = 228228227;
ld const EPS = 1e-10;

vector<ll> g[N];
bool used[N];

ll pdsu[N], rankdsu[N];

ll PDSU(ll v) {
    if (pdsu[v] == v) {
        return v;
    }

    return (pdsu[v] = PDSU(pdsu[v]));
}

void Unite(ll a, ll b) {
    a = PDSU(a);
    b = PDSU(b);
    if (rankdsu[a] > rankdsu[b]) {
        swap(a, b);
    }

    pdsu[a] = b;
    rankdsu[b] += rankdsu[a];
}

void zfunc(string s) {
    vector<ll> z;
    for (int i = 0; i < s.size(); ++i) {
        z.push_back(0);
    }
    ll l = 0, r = 0;
    for (int i = 1; i < s.size(); ++i) {
        if (r >= i) {
            z[i] = min(z[i - l], r - i + 1);
        }
        while (i + z[i] < s.size() && s[z[i]] == s[i + z[i]]) {
            z[i]++;
        }
        if (i + z[i] - 1 > r) {
            r = i + z[i] - 1;
            l = i;
        }
    }
}

void pfunc(string s) {
    vector<ll> p;
    for (int i = 0; i < s.size(); ++i) {
        p.push_back(0);
    }
    for (int i = 1; i < s.size(); ++i) {
        ll j = p[i - 1];
        while (j > 0 && s[i] != s[j]) {
            j = p[j - 1];
        }
        if (s[j] == s[i]) {
            ++j;
        }
        p[i] = j;
    }
}

void Dfs(ll v) {
    used[v] = true;
    for (int i = 0; i < g[v].size(); ++i) {
        if (! used[g[v][i]]) {
            Dfs(g[v][i]);
        }
    }
}

void Build(ll v, ll l, ll r) {
    if (r - l == 1) {
        return;
    }


    ll m = (l + r) / 2;
    Build(v * 2, l, m);
    Build(v * 2 + 1, m, r);
}

void Upd(ll v, ll l, ll r, ll pos, ll val) {
    if (r - l == 1 && l == pos) {
        return;
    }

    if (l > pos || r <= pos) {
        return;
    }

    ll m = (l + r) / 2;
    Upd(v * 2, l, m, pos, val);
    Upd(v * 2 + 1, m, r, pos, val);
}

ll Get(ll v, ll l, ll r, ll ql, ll qr) {
    if (l >= qr || r <= ql) {
        return 0;
    }

    if (l >= ql && r <= qr) {
        return 1;
    }

    ll m = (l + r) / 2;
    return Get(v * 2, l, m, ql, qr) + Get(v * 2 + 1, m, r, ql, qr);
}

struct Node {
    ll x, sz, pr;
    Node* left = nullptr;
    Node* right = nullptr;
    Node() {}
    Node(ll _x) {
        x = _x;
        sz = 1;
        pr = rand();
    }
};

ll GetSz(Node* tree) {
    return (tree ? tree->sz : 0);
}

void UpdSz(Node* tree) {
    tree->sz = GetSz(tree->left) + GetSz(tree->right) + 1;
}

Node* Merge(Node* left, Node* right) {
    if (! left) {
        return right;
    }
    if (! right) {
        return left;
    }

    if (left->pr > right->pr) {
        left->right = Merge(left->right, right);
        UpdSz(left);
        return left;
    }
    else {
        right->left = Merge(left, right->left);
        UpdSz(right);
        return right;
    }
}

pair<Node*, Node*> Split(Node* tree, ll x) {
    if (! tree) {
        return {tree, tree};
    }

    if (GetSz(tree->left) == x - 1) {
        auto tmp = tree->right;
        tree->right = nullptr;
        UpdSz(tree);
        return {tree, tmp};
    }
    else if (GetSz(tree->left) > x - 1) {
        auto tmp = Split(tree->left, x);
        tree->left = tmp.second;
        UpdSz(tree);
        return {tmp.first, tree};
    }
    else {
        auto tmp = Split(tree->right, x - GetSz(tree->left) - 1);
        tree->right = tmp.first;
        UpdSz(tree);
        return {tree, tmp.second};
    }
}

ll dist[N];
set<ll> go[N];

void Bfs(ll v) {
    used[v] = true;
    queue<ll> q;
    q.push(v);
    while (! q.empty()) {
        ll f = q.front();
        for (int i = 0; i < g[f].size(); ++i) {
            if (! used[g[f][i]]) {
                go[g[f][i]].insert(f);
                dist[g[f][i]] = dist[f] + 1;
                q.push(g[f][i]);
                used[g[f][i]] = true;
            }
            else {
                if (dist[g[f][i]] == dist[f] + 1) {
                    go[g[f][i]].insert(f);
                }
            }
        }
        q.pop();
    }
}

signed main() {
    ios_base::sync_with_stdio(false);
    cin.tie(NULL);
    cout.tie(NULL);

    srand(time(NULL));

    ll n, m;
    cin >> n >> m;
    for (int i = 0; i < m; ++i) {
        ll x, y;
        cin >> x >> y;
        g[y].push_back(x);
    }

    ll sz;
    cin >> sz;
    vector<ll> way;
    for (int i = 0; i < sz; ++i) {
        ll x;
        cin >> x;
        way.push_back(x);
    }

    Bfs(way.back());

    ll mn = 0, mx = 0;
    for (int i = 1; i < way.size(); ++i) {
        if (go[way[i - 1]].find(way[i]) != go[way[i - 1]].end()) {
            if (go[way[i - 1]].size() > 1) {
                mx++;
            }
        }
        else {
            mn++;
            mx++;
        }
    }

    cout << mn << ' ' << mx;

    return 0;
}
